==> haskell-yesod-test-1.6.16-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-test
version:              1.6.16
visibility:           public
id:                   yesod-test-1.6.16-7aGrWmByRUWCj7jY4NkZfb
key:                  yesod-test-1.6.16-7aGrWmByRUWCj7jY4NkZfb
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  a2d39d265211eb3a0683dbc61775b6e6
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.2.8/site-local/yesod-test-1.6.16
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yesod-test-1.6.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.16-7aGrWmByRUWCj7jY4NkZfb
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    aeson-2.1.2.1-F8qbdML4nHt6X1eCfIdgPU
    attoparsec-0.14.4-HI028cZ2WwJ53VFJd3R6KF base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    blaze-html-0.9.2.0-GaSrKu6gylZIYHIkWm02Ci
    blaze-markup-0.8.3.0-EKP12U2bGeIvH38eojwCH bytestring-0.11.4.0
    case-insensitive-1.2.1.0-KEn2hkRTWhZ23pGG8K2iDV
    conduit-1.3.6.1-GgxZHJrzNHqH6olM1r4h9q containers-0.6.5.1
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    hspec-core-2.10.9-1Qlio6Y322r310u8gnmAt6
    html-conduit-1.3.2.2-K06HmVTqJS64ipd94Aqih2
    http-types-0.12.4-10dv26SO8Qr9EY2Wk5cf3Y
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1 mtl-2.2.2
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 wai-3.2.4-KV6qTzqnsvLcunzNUsFns
    wai-extra-3.1.15-IvCRZFxJiOU9CcGshB9m4X
    xml-conduit-1.9.1.4-7WO2Ce9rY461KgJfKV86g2
    xml-types-0.3.8-LZyzf9bLT8K9kdiyyQ9IUF
    yesod-core-1.6.26.0-6z1r1oZbR0t64WgXOsjyUv

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.6.16-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-test
version:              1.6.16
visibility:           public
id:                   yesod-test-1.6.16-DVMMGQmSMpT4oTONk4XoXw
key:                  yesod-test-1.6.16-DVMMGQmSMpT4oTONk4XoXw
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  90834256ea62e79a78cc3b6f1fa04f22
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.2.8/site-local/yesod-test-1.6.16
library-dirs:         /usr/lib/ghc-9.2.8/site-local/yesod-test-1.6.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.16-DVMMGQmSMpT4oTONk4XoXw
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    aeson-2.1.2.1-F8qbdML4nHt6X1eCfIdgPU
    attoparsec-0.14.4-HI028cZ2WwJ53VFJd3R6KF base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    blaze-html-0.9.2.0-GaSrKu6gylZIYHIkWm02Ci
    blaze-markup-0.8.3.0-EKP12U2bGeIvH38eojwCH bytestring-0.11.4.0
    case-insensitive-1.2.1.0-KEn2hkRTWhZ23pGG8K2iDV
    conduit-1.3.6.1-Jlg4TYVmY3F9yB3akqN7Se containers-0.6.5.1
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    hspec-core-2.10.9-1Qlio6Y322r310u8gnmAt6
    html-conduit-1.3.2.2-6zDPVH467AA4QtNo2mlMok
    http-types-0.12.4-10dv26SO8Qr9EY2Wk5cf3Y
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1 mtl-2.2.2
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 wai-3.2.4-KV6qTzqnsvLcunzNUsFns
    wai-extra-3.1.15-EPNZIZGDcWL9L7VDHnR9Cf
    xml-conduit-1.9.1.4-HJACZVGZeNG65njlEmBXBf
    xml-types-0.3.8-LZyzf9bLT8K9kdiyyQ9IUF
    yesod-core-1.6.26.0-IFnyer9NSJuBnwI6ZRQ5JG

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
